package com.evobms.project.bms.service;

import java.util.List;
import com.evobms.project.bms.domain.BmsChargeDetail;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * BMS充电过程详细数据Service接口
 * 
 * @author tzy
 * @date 2026-02-23
 */
public interface IBmsChargeDetailService extends IService<BmsChargeDetail> {
    /**
     * 查询BMS充电过程详细数据
     * 
     * @param id BMS充电过程详细数据主键
     * @return BMS充电过程详细数据
     */
    public BmsChargeDetail selectBmsChargeDetailById(Long id);

    /**
     * 查询BMS充电过程详细数据列表
     * 
     * @param bmsChargeDetail BMS充电过程详细数据
     * @return BMS充电过程详细数据集合
     */
    public List<BmsChargeDetail> selectBmsChargeDetailList(BmsChargeDetail bmsChargeDetail);

    /**
     * 新增BMS充电过程详细数据
     * 
     * @param bmsChargeDetail BMS充电过程详细数据
     * @return 结果
     */
    public int insertBmsChargeDetail(BmsChargeDetail bmsChargeDetail);

    /**
     * 修改BMS充电过程详细数据
     * 
     * @param bmsChargeDetail BMS充电过程详细数据
     * @return 结果
     */
    public int updateBmsChargeDetail(BmsChargeDetail bmsChargeDetail);

    /**
     * 批量删除BMS充电过程详细数据
     * 
     * @param ids 需要删除的BMS充电过程详细数据主键集合
     * @return 结果
     */
    public int deleteBmsChargeDetailByIds(Long[] ids);

    /**
     * 删除BMS充电过程详细数据信息
     * 
     * @param id BMS充电过程详细数据主键
     * @return 结果
     */
    public int deleteBmsChargeDetailById(Long id);
}
