package com.evobms.project.bms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.evobms.framework.aspectj.lang.annotation.Log;
import com.evobms.framework.aspectj.lang.enums.BusinessType;
import com.evobms.project.bms.domain.BmsChargeDetail;
import com.evobms.project.bms.service.IBmsChargeDetailService;
import com.evobms.framework.web.controller.BaseController;
import com.evobms.framework.web.domain.AjaxResult;
import com.evobms.common.utils.poi.ExcelUtil;
import com.evobms.framework.web.page.TableDataInfo;

/**
 * BMS充电过程详细数据Controller
 *
 * @author tzy
 * @date 2026-02-23
 */
@RestController
@RequestMapping("/bms/chargedetail/data")
public class BmsChargeDetailController extends BaseController
{
    @Autowired
    private IBmsChargeDetailService bmsChargeDetailService;

    /**
     * 查询BMS充电过程详细数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(BmsChargeDetail bmsChargeDetail)
    {
        startPage();
        List<BmsChargeDetail> list = bmsChargeDetailService.selectBmsChargeDetailList(bmsChargeDetail);
        return getDataTable(list);
    }

    /**
     * 导出BMS充电过程详细数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:export')")
    @Log(title = "BMS充电过程详细数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsChargeDetail bmsChargeDetail)
    {
        List<BmsChargeDetail> list = bmsChargeDetailService.selectBmsChargeDetailList(bmsChargeDetail);
        ExcelUtil<BmsChargeDetail> util = new ExcelUtil<BmsChargeDetail>(BmsChargeDetail.class);
        util.exportExcel(response, list, "BMS充电过程详细数据数据");
    }

    /**
     * 获取BMS充电过程详细数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('bms:data:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmsChargeDetailService.selectBmsChargeDetailById(id));
    }

    /**
     * 新增BMS充电过程详细数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:add')")
    @Log(title = "BMS充电过程详细数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsChargeDetail bmsChargeDetail)
    {
        return toAjax(bmsChargeDetailService.insertBmsChargeDetail(bmsChargeDetail));
    }

    /**
     * 修改BMS充电过程详细数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:edit')")
    @Log(title = "BMS充电过程详细数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsChargeDetail bmsChargeDetail)
    {
        return toAjax(bmsChargeDetailService.updateBmsChargeDetail(bmsChargeDetail));
    }

    /**
     * 删除BMS充电过程详细数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:remove')")
    @Log(title = "BMS充电过程详细数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmsChargeDetailService.deleteBmsChargeDetailByIds(ids));
    }
}
